@@ -22,6 +22,9 @@ doc = """
 
     一些ansible相关的东西
 
+* jinaj2_util
+
+    jinja2的MemoryCache
 
 changes
 ---------------------------------------------------------
@@ -37,6 +40,11 @@ changes
 * 添加 common_util
 
 
+0.0.15
+>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
+
+* 添加jinaj2_util
+
 
 
 
