@@ -1,3 +1,4 @@
+import os
 import git
 import typing
 
@@ -17,7 +18,12 @@ def git_unstaged_and_untracked_file_list(proj_dir: [str, git.Repo]) -> typing.Li
         file_set.add(diff.b_path)
     file_list = list(file_set)
     file_list = file_list + repo.untracked_files
-    return file_list
+    filter_file_list = []
+    for name in file_list:
+        abs_path = os.path.abspath(repo.git_dir, name)
+        if os.path.exists(abs_path):
+            filter_file_list.append(name)
+    return filter_file_list
 
 
 def git_current_branch(proj_dir: str) -> str:
