@@ -6,6 +6,7 @@ class AssertMixin(object):
     """
     用于单元测试
     """
+
     def assert_record_and_map_equal(self, record: typing.Union[object, dict], pairs: dict):
         """
         从 `pairs` 里面的每个key, value, `record` 必然存在且相等
@@ -35,3 +36,20 @@ class AssertMixin(object):
             if ret:
                 break
             time.sleep(0.05)
+
+
+class RecordMixin(object):
+    """
+    一般用于单元测试
+    """
+    @classmethod
+    def record_mixin_attrs_get(cls, record, dict_or_keys):
+        def get_field(name):
+            if isinstance(record, dict):
+                return record[name]
+            return getattr(record, name)
+        if isinstance(dict_or_keys, dict):
+            dict_or_keys = list(dict_or_keys.keys())
+        dict_or_keys = list(dict_or_keys)
+        d = {key: get_field(key) for key in dict_or_keys}
+        return d
